@@ -1,7 +1,7 @@
 import sys
 
-author='Rocky Bernstein, Ned Batchelder, Paul Swartz, Allison Kaptur and others'
-author_email='rb@dustyfeet.com'
+author = "Rocky Bernstein, Ned Batchelder, Paul Swartz, Allison Kaptur and others"
+author_email = "rb@dustyfeet.com"
 entry_points = {"console_scripts": ["xpython=xpython.__main__:main"]}
 
 # Python-version | package | last-version |
@@ -12,21 +12,23 @@ entry_points = {"console_scripts": ["xpython=xpython.__main__:main"]}
 # 3.4            | pip     | 19.1.1       |
 
 import os.path as osp
+
+
 def get_srcdir():
     filename = osp.normcase(osp.dirname(osp.abspath(__file__)))
     return osp.realpath(filename)
 
+
 def read(*rnames):
     return open(osp.join(get_srcdir(), *rnames)).read()
 
+
 exec(read("xpython/version.py"))
 
 PYTHON_VERSION = sys.version_info[0] + (sys.version_info[1] / 10.0)
-IS_PYPY = '__pypy__' in sys.builtin_module_names
+IS_PYPY = "__pypy__" in sys.builtin_module_names
 
-supported_versions = (
-    SUPPORTED_PYPY if IS_PYPY else SUPPORTED_PYTHON
-)
+supported_versions = SUPPORTED_PYPY if IS_PYPY else SUPPORTED_PYTHON
 mess = "PYPY 2.7, 3.2, 3.5 and 3.6" if IS_PYPY else "CPython 2.7, 3.2 .. 3.7"
 
 if PYTHON_VERSION not in supported_versions:
@@ -35,19 +37,15 @@ if PYTHON_VERSION not in supported_versions:
     raise Exception(mess)
 
 if 3.0 <= PYTHON_VERSION <= 3.2:
-    click_version = '<= 4.0'
+    click_version = "<= 4.0"
 else:
-    click_version = ''
+    click_version = ""
 
-install_requires=[
-    "six",
-    "xdis >= 4.6.0, < 4.7.0",
-    "click%s" % click_version
-],
+install_requires = (["six", "xdis >= 4.6.1, < 4.7.0", "click%s" % click_version],)
 
 py_modules = None
 short_desc = "Python cross-version byte-code interpeter"
-url='http://github.com/rocky/xpython'
+url = "http://github.com/rocky/xpython"
 
 classifiers = [
     "Operating System :: OS Independent",
